==> bambooai-0.3.10.tar.gz: bambooai-0.3.10/bambooai/prompts.py <==
# prompts.py

# Default Example (Otherwise Pinecone Long Term Memory)
example_output = """
    import pandas as pd

    # Identify the dataframe `df`
    # df has already been defined and populated with the required data

    # Call the `describe()` method on `df`
    df_description = df.describe()

    # Print the output of the `describe()` method
    print(df_description)
    """
# Chain of Thought
task_evaluation = """
    You are an AI data analyst and your job is to assist the user with data analisys.
    The user asked the following question: '{}'.

    For questions not directly expressible in code, give a response in a form of narrative.

    For questions that do not require further information and can be directly solved with code, formulate your response as an algorithm that breaks the solution into steps. 
    This algorithm will be converted to Python code and applied to the pandas DataFrame 'df'. Here's the first row of 'df': {}.
    The DataFrame 'df' is already populated with necessary data.
    Present your algorithm in up to eight simple, clear English steps. If fewer steps suffice, that's acceptable. Remember to explain steps rather than write code.

    Finally, output your response using the QA_Response function.
    """
# Zero Shot Prompt
system_task = """
    You are an AI data analyst and your job is to assist user with analysing data in the pandas dataframe.
    The user will provide a dataframe named `df`, and a list of tasks to be accomplished using Python.
    The dataframe df has already been defined and populated with the required data.
    """
# One Shot Prompt
user_task = """
    You have been presented with a pandas dataframe named `df`.
    The dataframe df has already been defined and populated with the required data.
    The result of `print(df.head(1))` is:
    {}.
    Return the python code that acomplishes the following tasks: {}.
    Approach each task from the list in isolation, advancing to the next only upon its successful resolution. 
    Strictly adhere to the prescribed instructions to avoid oversights and ensure an accurate solution.
    Always include the import statements at the top of the code.
    Always include print statements to output the results of your code.
    Prefix the python code with <code> and suffix the code with </code>.

    Example Output:
    <code>
    {}
    </code>
    """
# Reflection
error_correct_task = """
    The execution of the code that you provided in the previous step resulted in an error.
    The error message is: {}
    Return a corrected python code that fixes the error.
    Always include the import statements at the top of the code, and comments and print statement where necessary.
    """
# Reflection
debug_code_task = """
    Your job as an AI QA engineer involves correcting and refactoring of the given Code so it deliveres the outcome as describe in the given Task list.

    Code:
    {}.
    Task list:
    {}.

    Please follow the below instructions to acoomplish your assingment.The dataframe df has already been defined and populated with the required data.

    Task Inspection:
    Go through the task list and the given Python code side by side.
    Ensure that each task in the list is accurately addressed by a corresponding section of code. Do not move on to the next task until the current one is completely solved and its implementation in the code is confirmed.

    Code Sectioning and Commenting:
    Based on the task list, divide the Python code into sections. Each task from the list should correspond to a distinct section of code.
    At the beginning of each section, insert a comment or header that clearly identifies the task that section of code addresses. This could look like "# Task 1: Identify the dataframe df for example."
    Ensure that the code within each section correctly and efficiently completes the task described in the comment or header for that section.

    After necessary modifications, provide the final, updated code, and a brief summary of the changes you made.
    Prefix the code with <code> and suffix the code with </code>.

    Example Input
    Task List:
    1. Identify the dataframe `df`.
    2. Call the `describe()` method on `df`.
    3. Print the output of the `describe()` method.

    Code: 
    df_description = df.describe()
    df_description

    Example Output:
    <code>
    import pandas as pd

    # Task 1: Identify the dataframe `df`
    # df has already been defined and populated with the required data

    # Task 2: Call the `describe()` method on `df`
    df_description = df.describe()

    # Task 3: Print the output of the `describe()` method
    print(df_description)
    </code>
 """
# Reflection
rank_answer = """
    As an AI QA Engineer, your role is to evaluate and grade the code: {}, supplied by the AI Data Analyst. You should rank it on a scale of 1 to 10.

    In your evaluation, consider factors such as the relevancy and accuracy of the solution in relation to the original assignment: {},
    presence of any errors or bugs, appropriateness of the inclusion of all given values, clarity of the code, and the completeness and format of each output.

    For most cases, your ranks should fall within the range of 5 to 7. Only exceptionally well-crafted codes that deliver exactly as per the desired outcome should score higher. 

    Please enclose your ranking in <rank></rank> tags.

    Example Output:
    <rank>6</rank>
    """
#Zero Shot Prompt
solution_insights = """
    You have been presented with the following task: {}, and asked to design a solution for it.
    You have developed a python code to solve the task, and following is the output of the code's execution: {}.
    Please provide a summary of the results attained by implementing your method.  
    Present this information in the most clear and comprehensible manner.
    Be certain to incorporate all relevant computations and outcomes.
    """

==> bambooai-0.3.11.tar.gz: bambooai-0.3.11/bambooai/prompts.py <==
# prompts.py

# Default Example (Otherwise Pinecone Long Term Memory)
example_output = """
    import pandas as pd

    # Identify the dataframe `df`
    # df has already been defined and populated with the required data

    # Call the `describe()` method on `df`
    df_description = df.describe()

    # Print the output of the `describe()` method
    print(df_description)
    """
# Select the expert to route the user's request to
task_classification = """
    You are an AI workflow routing specialist and your job is to route the user's request to the appropriate expert.
    The experts you have access to are as follows:

    1. A "Data Analyst" that can deal with any questions that can be directly solved with code utilizing dataframes.
    2. A "Data Analysis Theorist" that can answer questions about best practices and methods for extracting insights.    
    3. An "Internet Research Specialist" that can search the internet to find additional factual information, relevant data, and contextual details to help address user questions.
       This expert should be used when the question cannot be answered by the other two experts, or concerns a current event.

    The user asked the following question: '{}'.

    Can you please select the appropriate expert to best address this question?
  """

# Expert Tasks
analyst_task_evaluation = """
    You are an AI data analyst and your job is to assist the user with data analisys.
    The user asked the following question: '{}'.

    Formulate your response as an algorithm, breaking the solution into steps. This should be done in the context of previous conversations.
    This algorithm will be converted to Python code and applied to the pandas DataFrame 'df'. Here's the first row of 'df': {}.
    The DataFrame 'df' is already populated with necessary data.
    Present your algorithm in up to eight simple, clear English steps. If fewer steps suffice, that's acceptable. Remember to explain steps rather than write code.
    """
theorist_task_evaluation = """
    You are an AI data analysis theorist and your job is to educate the user.
    The user asked the following question: '{}'.

    Provide factual information responding directly to the user’s question. Include key details and context to ensure your response comprehensively answers their query.
    """
researcher_task_evaluation = """
    You are an AI internet research specialist and your job is to find the answer to the user's question.
    The user asked the following question: '{}'.
    
    Reframe the question into a search query as per the below examples.
    
    Example input: Can you please find out what is the popularity of Python programming language in 2023?
    Exaple output: Popularity of Python programming language in 2023
    """
# System promp for code generation
system_task = """
    You are an AI data analyst and your job is to assist user with analysing data in the pandas dataframe.
    The user will provide a dataframe named `df`, and a list of tasks to be accomplished using Python.
    The dataframe df has already been defined and populated with the required data.
    """
# User prompt for code generation
user_task = """
    You have been presented with a pandas dataframe named `df`.
    The dataframe df has already been defined and populated with the required data.
    The result of `print(df.head(1))` is:
    {}.
    Return the python code that acomplishes the following tasks: {}.
    Approach each task from the list in isolation, advancing to the next only upon its successful resolution. 
    Strictly adhere to the prescribed instructions to avoid oversights and ensure an accurate solution.
    Always include the import statements at the top of the code.
    Always include print statements to output the results of your code.
    Prefix the python code with <code> and suffix the code with </code>.

    Example Output:
    <code>
    {}
    </code>
    """
# Code error correction
error_correct_task = """
    The execution of the code that you provided in the previous step resulted in an error.
    The error message is: {}
    Return a corrected python code that fixes the error.
    Always include the import statements at the top of the code, and comments and print statement where necessary.
    """
# Code debug
debug_code_task = """
    Your job as an AI QA engineer involves correcting and refactoring of the given Code so it deliveres the outcome as describe in the given Task list.

    Code:
    {}.
    Task list:
    {}.

    Please follow the below instructions to acoomplish your assingment.The dataframe df has already been defined and populated with the required data.

    Task Inspection:
    Go through the task list and the given Python code side by side.
    Ensure that each task in the list is accurately addressed by a corresponding section of code. Do not move on to the next task until the current one is completely solved and its implementation in the code is confirmed.

    Code Sectioning and Commenting:
    Based on the task list, divide the Python code into sections. Each task from the list should correspond to a distinct section of code.
    At the beginning of each section, insert a comment or header that clearly identifies the task that section of code addresses. This could look like "# Task 1: Identify the dataframe df for example."
    Ensure that the code within each section correctly and efficiently completes the task described in the comment or header for that section.

    After necessary modifications, provide the final, updated code, and a brief summary of the changes you made.
    Prefix the code with <code> and suffix the code with </code>.

    Example Input
    Task List:
    1. Identify the dataframe `df`.
    2. Call the `describe()` method on `df`.
    3. Print the output of the `describe()` method.

    Code: 
    df_description = df.describe()
    df_description

    Example Output:
    <code>
    import pandas as pd

    # Task 1: Identify the dataframe `df`
    # df has already been defined and populated with the required data

    # Task 2: Call the `describe()` method on `df`
    df_description = df.describe()

    # Task 3: Print the output of the `describe()` method
    print(df_description)
    </code>
 """
# Code ranking
rank_answer = """
    As an AI QA Engineer, your role is to evaluate and grade the code: {}, supplied by the AI Data Analyst. You should rank it on a scale of 1 to 10.

    In your evaluation, consider factors such as the relevancy and accuracy of the obtained results: {} in relation to the original assignment: {},
    clarity of the code, and the completeness and format of outputs.

    For most cases, your ranks should fall within the range of 5 to 7. Only exceptionally well-crafted codes that deliver exactly as per the desired outcome should score higher. 
    
    Please enclose your ranking in <rank></rank> tags.

    Example Output:
    <rank>6</rank>
    """
# Code exec result summary
solution_insights = """
    You have been presented with the following task: {}, and asked to design a solution for it.
    You have crafted a Python code to resolve this task, and the output generated by the code's execution is as follows: {}.
    Please provide a summary of the results achieved through your method's implementation.
    Present this information in a manner that is both clear and easy to understand.
    Ensure that all results from the computations are included in your summary.
    """
